==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ToolActionGroupHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionGroupHeaderDescription } from "./ToolActionGroupHeaderDescription";
/**
 * @hidden
 */
var ToolActionGroupHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionGroupHeaderDescriptionMetadata, _super);
    function ToolActionGroupHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionGroupHeaderDescriptionMetadata.b = function (a) {
        if (ToolActionGroupHeaderDescriptionMetadata.a == null) {
            ToolActionGroupHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionGroupHeaderDescriptionMetadata.c(ToolActionGroupHeaderDescriptionMetadata.a);
        }
        if (a.g(ToolActionGroupHeaderDescriptionMetadata.a)) {
            return;
        }
        a.s(ToolActionGroupHeaderDescriptionMetadata.a);
    };
    ToolActionGroupHeaderDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionGroupHeaderDescriptionMetadata.d = function (a) {
        ToolActionGroupHeaderDescriptionMetadata.b(a);
        a.u("ToolActionGroupHeader", function () { return new ToolActionGroupHeaderDescription(); });
        a.t("ToolActionGroupHeader", ToolActionGroupHeaderDescriptionMetadata.a);
    };
    ToolActionGroupHeaderDescriptionMetadata.$t = markType(ToolActionGroupHeaderDescriptionMetadata, 'ToolActionGroupHeaderDescriptionMetadata');
    ToolActionGroupHeaderDescriptionMetadata.a = null;
    return ToolActionGroupHeaderDescriptionMetadata;
}(Base));
export { ToolActionGroupHeaderDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ToolActionGroupHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionGroupHeaderDescription } from "./ToolActionGroupHeaderDescription";
/**
 * @hidden
 */
var ToolActionGroupHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionGroupHeaderDescriptionMetadata, _super);
    function ToolActionGroupHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionGroupHeaderDescriptionMetadata.b = function (a) {
        if (ToolActionGroupHeaderDescriptionMetadata.a == null) {
            ToolActionGroupHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionGroupHeaderDescriptionMetadata.c(ToolActionGroupHeaderDescriptionMetadata.a);
        }
        if (a.j(ToolActionGroupHeaderDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionGroupHeaderDescriptionMetadata.a);
    };
    ToolActionGroupHeaderDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionGroupHeaderDescriptionMetadata.d = function (a) {
        ToolActionGroupHeaderDescriptionMetadata.b(a);
        a.aa("ToolActionGroupHeader", function () { return new ToolActionGroupHeaderDescription(); });
        a.z("ToolActionGroupHeader", ToolActionGroupHeaderDescriptionMetadata.a);
    };
    ToolActionGroupHeaderDescriptionMetadata.$t = markType(ToolActionGroupHeaderDescriptionMetadata, 'ToolActionGroupHeaderDescriptionMetadata');
    ToolActionGroupHeaderDescriptionMetadata.a = null;
    return ToolActionGroupHeaderDescriptionMetadata;
}(Base));
export { ToolActionGroupHeaderDescriptionMetadata };
